Description: OpenJij is a heuristic optimization library for the Ising model and QUBO. OpenJij can be easily written in Python. Let’s try to install OpenJij.

OpenJij

- Document
- GitHub
- Community
- Tutorials

OpenJij is a heuristic optimization library for the Ising model and QUBO. OpenJij can be easily written in Python. Let’s try to install OpenJij.
Try OpenJij

- Python document
- C++ document
- OpenJij Tutorial

## Install

$ pip install openjij

## OpenJij Tutorial

本チュートリアルの最終目的はOpenJijを使って、量子アニーリングを使った研究、実証実験などに向けた開発が行えるまでを目指します。
また量子アニーリングの基礎的なところから最先端の研究についてもコラムなどで紹介していく予定です。

Try Tutorial

## Community

This project is still going. If you can help, please join the OpenJij Slack community. Then, you can participate in the project, and ask questions.

Join theteam